aboutsummaryrefslogtreecommitdiff
path: root/wcsmbs/tst-wcstol-binary-gnu11.c
diff options
context:
space:
mode:
Diffstat (limited to 'wcsmbs/tst-wcstol-binary-gnu11.c')
-rw-r--r--wcsmbs/tst-wcstol-binary-gnu11.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/wcsmbs/tst-wcstol-binary-gnu11.c b/wcsmbs/tst-wcstol-binary-gnu11.c
index eb58550..f9d7b61 100644
--- a/wcsmbs/tst-wcstol-binary-gnu11.c
+++ b/wcsmbs/tst-wcstol-binary-gnu11.c
@@ -1,5 +1,5 @@
-/* Test wcstol functions with C2X binary integers (wide strings, GNU
- extensions, C2X wcstol features disabled).
+/* Test wcstol functions with C23 binary integers (wide strings, GNU
+ extensions, C23 wcstol features disabled).
Copyright (C) 2022-2024 Free Software Foundation, Inc.
This file is part of the GNU C Library.
@@ -20,15 +20,15 @@
#include <features.h>
/* This file tests the old versions of GNU extension functions, which
are not normally available to new binaries because GNU extensions
- normally imply C2X wcstol features. */
-#undef __GLIBC_USE_C2X_STRTOL
-#define __GLIBC_USE_C2X_STRTOL 0
+ normally imply C23 wcstol features. */
+#undef __GLIBC_USE_C23_STRTOL
+#define __GLIBC_USE_C23_STRTOL 0
#define CHAR wchar_t
#define WIDE 1
#define FNPFX wcsto
#define L_(C) L ## C
-#define TEST_C2X 0
+#define TEST_C23 0
#define TEST_Q 1
#define TEST_LOCALE 1